@@ -1,5 +1,4 @@
-from calendar import timegm
-from datetime import date
+from datetime import date, timedelta
 
 from .base import FormatColumn
 
@@ -9,10 +8,10 @@ class DateColumn(FormatColumn):
     py_types = (date, )
     format = 'H'
 
-    offset = 24 * 3600
+    epoch_start = date(1970, 1, 1)
 
     def before_write_item(self, value):
-        return timegm(value.timetuple()) // self.offset
+        return (value - self.epoch_start).days
 
     def after_read_item(self, value):
-        return date.fromtimestamp(value * self.offset)
+        return self.epoch_start + timedelta(value)
