@@ -1,7 +1,7 @@
 from .. import errors
 from .arraycolumn import create_array_column
 from .datecolumn import DateColumn
-from .datetimecolumn import DateTimeColumn
+from .datetimecolumn import create_datetime_column
 from . import exceptions as column_exceptions
 from .enumcolumn import create_enum_column
 from .floatcolumn import Float32, Float64
@@ -12,7 +12,7 @@ from .intcolumn import (
 from .nothingcolumn import NothingColumn
 from .nullcolumn import NullColumn
 from .nullablecolumn import create_nullable_column
-from .stringcolumn import String, FixedString
+from .stringcolumn import String, create_fixed_string_column
 from .uuidcolumn import UUIDColumn
 from .intervalcolumn import (
     IntervalYearColumn, IntervalMonthColumn, IntervalWeekColumn,
@@ -22,7 +22,7 @@ from .intervalcolumn import (
 
 
 column_by_type = {c.ch_type: c for c in [
-    DateColumn, DateTimeColumn, String, Float32, Float64,
+    DateColumn, String, Float32, Float64,
     Int8Column, Int16Column, Int32Column, Int64Column,
     UInt8Column, UInt16Column, UInt32Column, UInt64Column,
     NothingColumn, NullColumn, UUIDColumn,
@@ -39,11 +39,13 @@ def get_column_by_spec(spec, column_options=None):
         return get_column_by_spec(x, column_options)
 
     if spec.startswith('FixedString'):
-        length = int(spec[12:-1])
-        return FixedString(length)
+        return create_fixed_string_column(spec)
 
     elif spec.startswith('Enum'):
-        return create_enum_column(spec)
+        return create_enum_column(spec, column_options)
+
+    elif spec.startswith('DateTime'):
+        return create_datetime_column(spec, column_options)
 
     elif spec.startswith('Array'):
         return create_array_column(spec, create_column_with_options)
@@ -60,13 +62,18 @@ def get_column_by_spec(spec, column_options=None):
             raise errors.UnknownTypeError('Unknown type {}'.format(e.args[0]))
 
 
-def read_column(column_spec, n_items, buf):
-    column = get_column_by_spec(column_spec)
+def read_column(context, column_spec, n_items, buf):
+    column_options = {'context': context}
+    column = get_column_by_spec(column_spec, column_options=column_options)
     return column.read_data(n_items, buf)
 
 
-def write_column(column_name, column_spec, items, buf, types_check=False):
-    column_options = {'types_check': types_check}
+def write_column(context, column_name, column_spec, items, buf,
+                 types_check=False):
+    column_options = {
+        'context': context,
+        'types_check': types_check
+    }
     column = get_column_by_spec(column_spec, column_options)
 
     try:
