@@ -34,7 +34,7 @@ class ErrorCodes(object):
     CANNOT_READ_COMPRESSED_CHUNK = 31
     ATTEMPT_TO_READ_AFTER_EOF = 32
     CANNOT_READ_ALL_DATA = 33
-    TOO_MUCH_ARGUMENTS_FOR_FUNCTION = 34
+    TOO_MANY_ARGUMENTS_FOR_FUNCTION = 34
     TOO_LESS_ARGUMENTS_FOR_FUNCTION = 35
     BAD_ARGUMENTS = 36
     UNKNOWN_ELEMENT_IN_AST = 37
@@ -118,7 +118,6 @@ class ErrorCodes(object):
     UNKNOWN_SETTING = 115
     THERE_IS_NO_DEFAULT_VALUE = 116
     INCORRECT_DATA = 117
-    TABLE_METADATA_DOESNT_EXIST = 118
     ENGINE_REQUIRED = 119
     CANNOT_INSERT_VALUE_OF_DIFFERENT_SIZE_INTO_TUPLE = 120
     UNKNOWN_SET_DATA_VARIANT = 121
@@ -157,15 +156,15 @@ class ErrorCodes(object):
     UNKNOWN_RELATION = 155
     DICTIONARIES_WAS_NOT_LOADED = 156
     ILLEGAL_OVERFLOW_MODE = 157
-    TOO_MUCH_ROWS = 158
+    TOO_MANY_ROWS = 158
     TIMEOUT_EXCEEDED = 159
     TOO_SLOW = 160
-    TOO_MUCH_COLUMNS = 161
+    TOO_MANY_COLUMNS = 161
     TOO_DEEP_SUBQUERIES = 162
     TOO_DEEP_PIPELINE = 163
     READONLY = 164
-    TOO_MUCH_TEMPORARY_COLUMNS = 165
-    TOO_MUCH_TEMPORARY_NON_CONST_COLUMNS = 166
+    TOO_MANY_TEMPORARY_COLUMNS = 165
+    TOO_MANY_TEMPORARY_NON_CONST_COLUMNS = 166
     TOO_DEEP_AST = 167
     TOO_BIG_AST = 168
     BAD_TYPE_OF_FIELD = 169
@@ -200,7 +199,7 @@ class ErrorCodes(object):
     UNKNOWN_QUOTA = 199
     QUOTA_DOESNT_ALLOW_KEYS = 200
     QUOTA_EXPIRED = 201
-    TOO_MUCH_SIMULTANEOUS_QUERIES = 202
+    TOO_MANY_SIMULTANEOUS_QUERIES = 202
     NO_FREE_CONNECTION = 203
     CANNOT_FSYNC = 204
     NESTED_TYPE_TOO_DEEP = 205
@@ -243,20 +242,18 @@ class ErrorCodes(object):
     TABLE_IS_READ_ONLY = 242
     NOT_ENOUGH_SPACE = 243
     UNEXPECTED_ZOOKEEPER_ERROR = 244
-    INVALID_NESTED_NAME = 245
     CORRUPTED_DATA = 246
     INCORRECT_MARK = 247
     INVALID_PARTITION_VALUE = 248
     NOT_ENOUGH_BLOCK_NUMBERS = 250
     NO_SUCH_REPLICA = 251
-    TOO_MUCH_PARTS = 252
+    TOO_MANY_PARTS = 252
     REPLICA_IS_ALREADY_EXIST = 253
     NO_ACTIVE_REPLICAS = 254
-    TOO_MUCH_RETRIES_TO_FETCH_PARTS = 255
+    TOO_MANY_RETRIES_TO_FETCH_PARTS = 255
     PARTITION_ALREADY_EXISTS = 256
     PARTITION_DOESNT_EXIST = 257
     UNION_ALL_RESULT_STRUCTURES_MISMATCH = 258
-    UNION_ALL_COLUMN_ALIAS_MISMATCH = 259
     CLIENT_OUTPUT_FORMAT_SPECIFIED = 260
     UNKNOWN_BLOCK_INFO_FIELD = 261
     BAD_COLLATION = 262
@@ -303,47 +300,22 @@ class ErrorCodes(object):
     CANNOT_WAITPID = 304
     TABLE_WAS_NOT_DROPPED = 305
     TOO_DEEP_RECURSION = 306
-    TOO_MUCH_BYTES = 307
+    TOO_MANY_BYTES = 307
     UNEXPECTED_NODE_IN_ZOOKEEPER = 308
     FUNCTION_CANNOT_HAVE_PARAMETERS = 309
-    INCONSISTENT_TABLE_ACCROSS_SHARDS = 310
-    INSUFFICIENT_SPACE_FOR_RESHARDING = 311
-    PARTITION_COPY_FAILED = 312
-    PARTITION_ATTACH_FAILED = 313
-    RESHARDING_NO_WORKER = 314
-    INVALID_PARTITIONS_INTERVAL = 315
-    RESHARDING_INVALID_PARAMETERS = 316
     INVALID_SHARD_WEIGHT = 317
     INVALID_CONFIG_PARAMETER = 318
     UNKNOWN_STATUS_OF_INSERT = 319
-    DUPLICATE_SHARD_PATHS = 320
     VALUE_IS_OUT_OF_RANGE_OF_DATA_TYPE = 321
-    RESHARDING_BUSY_CLUSTER = 322
-    RESHARDING_BUSY_SHARD = 323
-    RESHARDING_NO_SUCH_COORDINATOR = 324
-    RESHARDING_NO_COORDINATOR_MEMBERSHIP = 325
-    RESHARDING_ALREADY_SUBSCRIBED = 326
-    RESHARDING_REMOTE_NODE_UNAVAILABLE = 327
-    RESHARDING_REMOTE_NODE_ERROR = 328
-    RESHARDING_COORDINATOR_DELETED = 329
-    RESHARDING_DISTRIBUTED_JOB_ON_HOLD = 330
-    RESHARDING_INVALID_QUERY = 331
-    RESHARDING_INITIATOR_CHECK_FAILED = 332
-    RWLOCK_ALREADY_HELD = 333
-    RWLOCK_NO_SUCH_LOCK = 334
     BARRIER_TIMEOUT = 335
     UNKNOWN_DATABASE_ENGINE = 336
     DDL_GUARD_IS_ACTIVE = 337
-    NO_SUCH_BARRIER = 338
-    RESHARDING_ILL_FORMED_LOG = 339
-    NO_ZOOKEEPER_ACCESSOR = 340
     UNFINISHED = 341
     METADATA_MISMATCH = 342
     SUPPORT_IS_DISABLED = 344
     TABLE_DIFFERS_TOO_MUCH = 345
     CANNOT_CONVERT_CHARSET = 346
     CANNOT_LOAD_CONFIG = 347
-    RESHARDING_NULLABLE_SHARDING_KEY = 348
     CANNOT_INSERT_NULL_IN_ORDINARY_COLUMN = 349
     INCOMPATIBLE_SOURCE_TABLES = 350
     AMBIGUOUS_TABLE_NAME = 351
@@ -362,7 +334,7 @@ class ErrorCodes(object):
     RECEIVED_ERROR_TOO_MANY_REQUESTS = 364
     OUTPUT_IS_NOT_SORTED = 365
     SIZES_OF_NESTED_COLUMNS_ARE_INCONSISTENT = 366
-    TOO_MUCH_FETCHES = 367
+    TOO_MANY_FETCHES = 367
     BAD_CAST = 368
     ALL_REPLICAS_ARE_STALE = 369
     DATA_TYPE_CANNOT_BE_USED_IN_TABLES = 370
@@ -377,12 +349,31 @@ class ErrorCodes(object):
     UNKNOWN_STATUS_OF_DISTRIBUTED_DDL_TASK = 379
     CANNOT_KILL = 380
     HTTP_LENGTH_REQUIRED = 381
+    CANNOT_LOAD_CATBOOST_MODEL = 382
+    CANNOT_APPLY_CATBOOST_MODEL = 383
+    PART_IS_TEMPORARILY_LOCKED = 384
+    MULTIPLE_STREAMS_REQUIRED = 385
+    NO_COMMON_TYPE = 386
+    EXTERNAL_LOADABLE_ALREADY_EXISTS = 387
+    CANNOT_ASSIGN_OPTIMIZE = 388
+    INSERT_WAS_DEDUPLICATED = 389
+    CANNOT_GET_CREATE_TABLE_QUERY = 390
+    EXTERNAL_LIBRARY_ERROR = 391
+    QUERY_IS_PROHIBITED = 392
+    THERE_IS_NO_QUERY = 393
+    QUERY_WAS_CANCELLED = 394
+    FUNCTION_THROW_IF_VALUE_IS_NON_ZERO = 395
+    TOO_MANY_ROWS_OR_BYTES = 396
+    QUERY_IS_NOT_SUPPORTED_IN_MATERIALIZED_VIEW = 397
 
     KEEPER_EXCEPTION = 999
     POCO_EXCEPTION = 1000
     STD_EXCEPTION = 1001
     UNKNOWN_EXCEPTION = 1002
 
+    CONDITIONAL_TREE_PARENT_NOT_FOUND = 2001
+    ILLEGAL_PROJECTION_MANIPULATOR = 2002
+
 
 if compat.PY3:
     class Error(Exception):
